*******************************************************************************
*The SAS program (HEI2010_ASA24-2016_IndividualScore_Perday.sas):             *
*									           *
*This SAS program can be used to calculate Healthy Eating Index (HEI)-2010    *
*scores from 24-hour recall data collected using ASA24-2016. This program     *
*calculates HEI-2010 component and total scores for each recall (i.e., each   *
*individuals reported 1-day intake).  Additional code that calculates        *
*HEI-2010 component and total scores for multiple 24HRs is available on the   * 
*ASA24 HEI Resources page.		                                         *
*									           *
*This program has been tested using SAS, version 9.4 and uses the 'Totals'    *
*analysis file from ASA24-2016.  These program files can be downloaded from   *
*the Researcher Web site. The data file should be in CSV format.	           *
*									           *
*Note: Some users have found that the SAS program will drop observations from *
*the analysis if the ID field is not the same length for all observations.  To* 
*prevent this error, the observations with the longest ID length should be    *
*listed first when the data is imported into SAS.			           *
*								                  *
*				            			                  *
*									           *
*Please see accompanying readme file.   				           *
*******************************************************************************;

/* Filenames for the input datasets.*/
filename Totals 'C:/Totals.csv'; /*Daily Total Nutrient and Pyramid Equivalents file from ASA24-2016*/

/*Name and location of the output file to be exported, containing HEI-2010 component and total scores for each intake day*/
filename res 'C:/hei2010.individual.result.csv';

/*Read in required macros*/

%include 'C:/hei2010.beanspeas.allocation.macro.doc.sas';
%include 'C:/hei2010.score.macro.doc.sas';


TITLE 'ASA24-2016 HEI-2010 scores - by person per day';


/*Step 1.
Inputs daily total data and create five additional required variables.  These variables are:  
WHOLEFRT, MONOPOLY, ALLMEAT, SEAPLANT, and EMPTYCAL10
*/

Proc import datafile=Totals
  Out=Totals
  Dbms=csv
  Replace;
  Getnames=yes;
Run;


DATA Totals;
  SET Totals;
  
  WHOLEFRT=F_CITMLB+F_OTHER;
  MONOPOLY=MFAT+PFAT;
  ALLMEAT=PF_MPS_TOTAL+PF_EGGS+PF_NUTSDS+PF_SOY;
  SEAPLANT=PF_SEAFD_HI+PF_SEAFD_LOW+PF_SOY+PF_NUTSDS;
 /**Calculate intake of Calories from SoFAAS**/

      ADDSUGC=16*ADD_SUGARS;	/*calories from added sugars*/
      SOLFATC=9*SOLID_FATS;	/*calories from solid fat*/

      maxalcgr=13*(kcal/1000);  /*max grams of alcohol based on kcal intake*/

      if ALC <= maxalcgr then EXALCCAL=0;  /*consumed less than max*/
        else if ALC > maxalcgr then EXALCCAL=7*(ALC-maxalcgr);  /*get cal from extra alc grams*/

      EMPTYCAL10=ADDSUGC+SOLFATC+EXALCCAL; /*total empty calories in hei2010 definition*/
run; 

/*Step 2.
Runs the macro to properly allocate the intakes of the FPED variable Legumes (V_LEGUMES)
 (NOT PF_LEGUMES) to either Total Protein Foods and Seafood and Plant Proteins (ALLMEAT 
 and SEAPLANT) or Total Vegetables and Greens and Beans (V_TOTAL and V_DRKGR). The four resulting
 variables from this step, named LEGUME_ADDED_V_TOTAL, LEGUME_ADDED_BEANGRN,
 LEGUME_ADDED_ALLMEAT, and LEGUME_ADDED_SEAPLANT are all used in the next step. 
*/

%LEG2010A (indat=Totals,
           kcal=KCAL,
           allmeat=ALLMEAT,
	   seaplant=SEAPLANT,
	   v_total=V_TOTAL,
	   v_drkgr=V_DRKGR,
	   legumes=V_LEGUMES,
	   outdat=afterleg);


/*Step 3. 
 Runs the HEI2010 scoring macro which calculates intake density amounts and HEI scores.
*/

%HEI2010 (indat=afterleg,
          kcal=KCAL,
	  lv_total= LEGUME_ADDED_V_TOTAL,
	  lbeangrn= LEGUME_ADDED_BEANGRN,
	  f_total=F_TOTAL,
	  wholefrt=WHOLEFRT,
	  g_whl=G_WHOLE,
	  d_total=D_TOTAL,
          lallmeat= LEGUME_ADDED_ALLMEAT,
	  lseaplant= LEGUME_ADDED_SEAPLANT,
	  monopoly=MONOPOLY,
	  sfat=SFAT,
	  sodi=SODI,
	  G_NWHL=G_REFINED,
	  EMPTYCAL10=EMPTYCAL10,
	  outdat=hei2010);
 
run;

/*Step 4.
 Displays and saves the results.
*/ 

Data hei2010r (keep=UserName UserID RecallNo kcal HEIX1_TOTALVEG HEIX2_GREEN_AND_BEAN HEIX3_TOTALFRUIT
     HEIX4_WHOLEFRUIT HEIX5_WHOLEGRAIN HEIX6_TOTALDAIRY HEIX7_TOTPROT HEIX8_SEAPLANT_PROT
     HEIX9_FATTYACID HEIX10_SODIUM HEIX11_REFINEDGRAIN HEIX12_SOFAAS
     HEI2010_TOTAL_SCORE);
  Set hei2010;
  Run;

proc means n nmiss min max mean data=hei2010r;
run;

proc export data= hei2010r
  file=res
  dbms=csv
  replace;
run;

